% Solution of the Matlab Exercise, Sheet 2
% (see http://syscop.de/teaching/2016/systemtheorie-und-regelungstechnik-1)

% AUTHOR: Florian Messerer
% Systems control and optimization laboratory, 
% Department of Microsystems Engineering (IMTEK),
% University of Freiburg
% 
% File Created: 16.05.2016

clear all % clear workspace
close all % close all open figures

%% Task 1a)
DT = 5e-4; % time step in seconds
numSteps = 1000; % number of simulated time steps
x0 = [0;0]; % initial value
T_U = linspace(0,numSteps*DT, numSteps); % time grid of control U (U = const)
U_const = ones(1,numSteps); % control sequence
[X,Y,T] = nlsim(@RLC_ode, x0, U_const, DT, @RLC_output);

figure(1)
plot(T,Y,T_U,U_const)
xlabel('t in s')
ylabel('voltage in V')
legend('v_C','u')
title('Response of RLC circuit to constant control input')

%% Task 1b)
omega = 2*pi*5; % angular frequency
U_square = .5+ .5*square(omega*T_U); % square signal with angular frequency omega
[X2,Y2,T2] = nlsim(@RLC_ode, x0, U_square, DT, @RLC_output);

figure(2)
plot(T2,Y2,T_U,U_square)
xlabel('t in s')
ylabel('voltage in V')
legend('v_C','u')
title('Response of RLC circuit to square signal control input')

%%  Task 2a)
% definition of parameters
R = 25; % Ohm
L = .2; % Henry
C = 50e-6; % Farad

% definition of system matrices
A = [0   1/C;
    -1/L -R/L];
B = [0; 1/L];
C = [1,0];
D = 0;
% create state space model
RLC_ss  = ss(A,B,C,D);

%% Task 2b)

figure(3) % lsim() will use this figure for plotting
lsim(RLC_ss,U_const,T_U,x0) % U_const and T_U defined in 1 a)
% lsim(RLC_ss,U_const,T_U) will give the same result because x0 = [0;0]

%alternative:
% [Y,T,X] = lsim(RLC_ss, U_const,T_U) 
% results will be saved but plotting has to be done manually

%% Task 2c)

figure(4) % step() will use this figure for plotting
step(RLC_ss) % get step response of the system

%alternative:
% [Y,T,X] = step(RLC_ss) % or
% [Y,T] = step(RLC_ss)
% results will be saved but plotting has to be done manually

%% Task 2d)

figure(5) % lsim() will use this figure for plotting
lsim(RLC_ss,U_square,T_U,x0) % U_square defined in 1b)
% lsim(RLC_ss,U_square,T_U) will give the same result because x0 = [0;0]

%alternative:
% [Y,T,X] = lsim(RLC_ss, U_square,T_U) 
% results will be saved but plotting has to be done manually